"""

Crawler module for executing scraping configurations

"""



from .resource_processor import ResourceProcessor

from .execution_engine import ExecutionEngine



__all__ = ["ResourceProcessor", "ExecutionEngine"]
